summaryrefslogtreecommitdiffstats
path: root/scripts
diff options
context:
space:
mode:
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/gen_run_tests.py2
-rwxr-xr-xscripts/gen_travis.py15
2 files changed, 10 insertions, 7 deletions
diff --git a/scripts/gen_run_tests.py b/scripts/gen_run_tests.py
index 729ecb1..9e46ba9 100755
--- a/scripts/gen_run_tests.py
+++ b/scripts/gen_run_tests.py
@@ -18,7 +18,7 @@ possible_config_opts = [
'--enable-debug',
'--enable-prof',
'--disable-stats',
- '--disable-tcache',
+ '--with-malloc-conf=tcache:false',
]
print 'set -e'
diff --git a/scripts/gen_travis.py b/scripts/gen_travis.py
index 35a10ee..4649cb7 100755
--- a/scripts/gen_travis.py
+++ b/scripts/gen_travis.py
@@ -24,11 +24,11 @@ script:
# The 'default' configuration is gcc, on linux, with no compiler or configure
# flags. We also test with clang, -m32, --enable-debug, --enable-prof,
# --disable-stats, and --disable-tcache. To avoid abusing travis though, we
# don't test all 2**7 = 128 possible combinations of these; instead, we only
# test combinations of up to 2 'unusual' settings, under the hope that bugs
# involving interactions of such settings are rare.
# things at once, for C(7, 0) + C(7, 1) + C(7, 2) = 29
MAX_UNUSUAL_OPTIONS = 2
os_default = 'linux'
@@ -40,7 +40,10 @@ compilers_unusual = 'CC=clang CXX=clang++'
compiler_flag_unusuals = ['-m32']
configure_flag_unusuals = [
- '--enable-debug', '--enable-prof', '--disable-stats', '--disable-tcache',
+ '--enable-debug',
+ '--enable-prof',
+ '--disable-stats',
+ '--with-malloc-conf=tcache:false',
]
all_unusuals = (
@@ -24,11 +24,11 @@ script:
# The 'default' configuration is gcc, on linux, with no compiler or configure
# flags. We also test with clang, -m32, --enable-debug, --enable-prof,
-# --disable-stats, and --disable-tcache. To avoid abusing travis though, we
-# don't test all 2**7 = 128 possible combinations of these; instead, we only
-# test combinations of up to 2 'unusual' settings, under the hope that bugs
-# involving interactions of such settings are rare.
-# things at once, for C(7, 0) + C(7, 1) + C(7, 2) = 29
+# --disable-stats, and --with-malloc-conf=tcache:false. To avoid abusing
+# travis though, we don't test all 2**7 = 128 possible combinations of these;
+# instead, we only test combinations of up to 2 'unusual' settings, under the
+# hope that bugs involving interactions of such settings are rare.
+# Things at once, for C(7, 0) + C(7, 1) + C(7, 2) = 29
MAX_UNUSUAL_OPTIONS = 2
os_default = 'linux'